@@ -5,7 +5,7 @@
 
 from badsecrets.base import check_all_modules, carve_all_modules, hashcat_all_modules
 from badsecrets.helpers import print_status
-import pkg_resources
+from importlib.metadata import version, PackageNotFoundError
 import requests
 import argparse
 import sys
@@ -21,7 +21,7 @@ requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
 SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(os.path.dirname(SCRIPT_DIR))
 
-ascii_art_banner = """
+ascii_art_banner = r"""
  __ )              |                                |         
  __ \    _` |   _` |   __|   _ \   __|   __|   _ \  __|   __| 
  |   |  (   |  (   | \__ \   __/  (     |      __/  |   \__ \ 
@@ -30,10 +30,12 @@ ____/  \__,_| \__,_| ____/ \___| \___| _|    \___| \__| ____/
 
 
 def print_version():
-    version = pkg_resources.get_distribution("badsecrets").version
-    if version == "0.0.0":
-        version = "ersion Unknown (Running w/poetry?)"
-    print(f"v{version}\n")
+    try:
+        dist_version = version("badsecrets")
+    except PackageNotFoundError:
+        dist_version = "ersion Unknown (Running w/poetry?)"
+
+    print(f"v{dist_version}\n")
 
 
 class CustomArgumentParser(argparse.ArgumentParser):
